Enum openidconnect::core::CoreAuthDisplay
source · pub enum CoreAuthDisplay {
Page,
Popup,
Touch,
Wap,
Extension(String),
}Expand description
How the Authorization Server displays the authentication and consent user interface pages to the End-User.
These values are defined in Section 3.1.2.1.
Variants
Page
The Authorization Server SHOULD display the authentication and consent UI consistent with a full User Agent page view. If the display parameter is not specified, this is the default display mode.
Popup
The Authorization Server SHOULD display the authentication and consent UI consistent with a popup User Agent window. The popup User Agent window should be of an appropriate size for a login-focused dialog and should not obscure the entire window that it is popping up over.
Touch
The Authorization Server SHOULD display the authentication and consent UI consistent with a device that leverages a touch interface.
Wap
The Authorization Server SHOULD display the authentication and consent UI consistent with a “feature phone” type display.
Extension(String)
An extension not defined by the OpenID Connect Core spec.