pub struct Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,{ /* private fields */ }Expand description
OpenID Connect client.
Error Types
To enable compile time verification that only the correct and complete set of errors for the Client function being
invoked are exposed to the caller, the Client type is specialized on multiple implementations of the
ErrorResponse trait. The exact ErrorResponse implementation returned varies by the RFC that the invoked
Client function implements:
- Generic type
TE(aka Token Error) for errors defined by RFC 6749 OAuth 2.0 Authorization Framework. - Generic type
TRE(aka Token Revocation Error) for errors defined by RFC 7009 OAuth 2.0 Token Revocation.
For example when revoking a token, error code unsupported_token_type (from RFC 7009) may be returned:
let res = client
.revoke_token(AccessToken::new("some token".to_string()).into())
.unwrap()
.request(&http_client);
assert!(matches!(res, Err(
RequestTokenError::ServerResponse(err)) if matches!(err.error(),
RevocationErrorResponseType::UnsupportedTokenType)));Implementations
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointNotSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointNotSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
Sourcepub fn new(
client_id: ClientId,
issuer: IssuerUrl,
jwks: JsonWebKeySet<K>,
) -> Self
pub fn new( client_id: ClientId, issuer: IssuerUrl, jwks: JsonWebKeySet<K>, ) -> Self
Initialize an OpenID Connect client.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointMaybeSet, EndpointMaybeSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointMaybeSet, EndpointMaybeSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
Sourcepub fn from_provider_metadata<A, CA, CN, CT, G, JK, RM, RS, S>(
provider_metadata: ProviderMetadata<A, AD, CA, CN, CT, G, JE, JK, K, RM, RS, S>,
client_id: ClientId,
client_secret: Option<ClientSecret>,
) -> Selfwhere
A: AdditionalProviderMetadata,
CA: ClientAuthMethod,
CN: ClaimName,
CT: ClaimType,
G: GrantType,
JK: JweKeyManagementAlgorithm,
RM: ResponseMode,
RS: ResponseType,
S: SubjectIdentifierType,
pub fn from_provider_metadata<A, CA, CN, CT, G, JK, RM, RS, S>(
provider_metadata: ProviderMetadata<A, AD, CA, CN, CT, G, JE, JK, K, RM, RS, S>,
client_id: ClientId,
client_secret: Option<ClientSecret>,
) -> Selfwhere
A: AdditionalProviderMetadata,
CA: ClientAuthMethod,
CN: ClaimName,
CT: ClaimType,
G: GrantType,
JK: JweKeyManagementAlgorithm,
RM: ResponseMode,
RS: ResponseType,
S: SubjectIdentifierType,
Initialize an OpenID Connect client from OpenID Connect Discovery provider metadata.
Use ProviderMetadata::discover or
ProviderMetadata::discover_async to fetch the provider metadata.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Sourcepub fn set_auth_type(self, auth_type: AuthType) -> Self
pub fn set_auth_type(self, auth_type: AuthType) -> Self
Set the type of client authentication used for communicating with the authorization server.
The default is to use HTTP Basic authentication, as recommended in
Section 2.3.1 of RFC 6749. Note that
if a client secret is omitted (i.e., set_client_secret() is not
called), AuthType::RequestBody is used regardless of the auth_type passed to
this function.
Sourcepub fn auth_type(&self) -> &AuthType
pub fn auth_type(&self) -> &AuthType
Return the type of client authentication used for communicating with the authorization server.
Sourcepub fn set_auth_uri(
self,
auth_uri: AuthUrl,
) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointSet, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>
pub fn set_auth_uri( self, auth_uri: AuthUrl, ) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointSet, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>
Set the authorization endpoint.
The client uses the authorization endpoint to obtain authorization from the resource owner via user-agent redirection. This URL is used in all standard OAuth2 flows except the Resource Owner Password Credentials Grant and the Client Credentials Grant.
Sourcepub fn set_client_secret(self, client_secret: ClientSecret) -> Self
pub fn set_client_secret(self, client_secret: ClientSecret) -> Self
Set the client secret.
A client secret is generally used for confidential (i.e., server-side) OAuth2 clients and omitted from public (browser or native app) OAuth2 clients (see RFC 8252).
Set the RFC 8628 device authorization endpoint used for the Device Authorization Flow.
Sourcepub fn set_introspection_url(
self,
introspection_url: IntrospectionUrl,
) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, EndpointSet, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>
pub fn set_introspection_url( self, introspection_url: IntrospectionUrl, ) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, EndpointSet, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>
Set the RFC 7662 introspection endpoint.
See introspect().
Sourcepub fn set_redirect_uri(self, redirect_url: RedirectUrl) -> Self
pub fn set_redirect_uri(self, redirect_url: RedirectUrl) -> Self
Set the redirect URL used by the authorization endpoint.
Sourcepub fn redirect_uri(&self) -> Option<&RedirectUrl>
pub fn redirect_uri(&self) -> Option<&RedirectUrl>
Return the redirect URL used by the authorization endpoint.
Sourcepub fn set_revocation_url(
self,
revocation_uri: RevocationUrl,
) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, EndpointSet, HasTokenUrl, HasUserInfoUrl>
pub fn set_revocation_url( self, revocation_uri: RevocationUrl, ) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, EndpointSet, HasTokenUrl, HasUserInfoUrl>
Set the RFC 7009 revocation endpoint.
See revoke_token().
Sourcepub fn set_token_uri(
self,
token_uri: TokenUrl,
) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, EndpointSet, HasUserInfoUrl>
pub fn set_token_uri( self, token_uri: TokenUrl, ) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, EndpointSet, HasUserInfoUrl>
Set the token endpoint.
The client uses the token endpoint to exchange an authorization code for an access token, typically with client authentication. This URL is used in all standard OAuth2 flows except the Implicit Grant.
Sourcepub fn set_user_info_url(
self,
userinfo_endpoint: UserInfoUrl,
) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, EndpointSet>
pub fn set_user_info_url( self, userinfo_endpoint: UserInfoUrl, ) -> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, EndpointSet>
Set the user info endpoint.
See user_info().
Sourcepub fn enable_openid_scope(self) -> Self
pub fn enable_openid_scope(self) -> Self
Enable the openid scope to be requested automatically.
This scope is requested by default, so this function is only useful after previous calls to
disable_openid_scope.
Sourcepub fn disable_openid_scope(self) -> Self
pub fn disable_openid_scope(self) -> Self
Disable the openid scope from being requested automatically.
Sourcepub fn id_token_verifier(&self) -> IdTokenVerifier<'_, K>
pub fn id_token_verifier(&self) -> IdTokenVerifier<'_, K>
Return an ID token verifier for use with the IdToken::claims
method.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointSet, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring an authorization endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, EndpointSet, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring an authorization endpoint.
Generate an authorization URL for a new authorization request.
Requires set_auth_uri() to have been previously
called to set the authorization endpoint.
NOTE: Passing authorization request parameters as a JSON Web Token
instead of URL query parameters is not currently supported. The
claims parameter
is also not directly supported, although the AuthorizationRequest::add_extra_param
method can be used to add custom parameters, including claims.
Arguments
authentication_flow- The authentication flow to use (code, implicit, or hybrid).state_fn- A function that returns an opaque value used by the client to maintain state between the request and callback. The authorization server includes this value when redirecting the user-agent back to the client.nonce_fn- Similar tostate_fn, but used to generate an opaque nonce to be used when verifying the ID token returned by the OpenID Connect Provider.
Security Warning
Callers should use a fresh, unpredictable state for each authorization request and verify
that this value matches the state parameter passed by the authorization server to the
redirect URI. Doing so mitigates
Cross-Site Request Forgery
attacks.
Similarly, callers should use a fresh, unpredictable nonce to help protect against ID
token reuse and forgery.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, EndpointSet, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring a token endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, EndpointSet, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring a token endpoint.
Sourcepub fn exchange_client_credentials(
&self,
) -> ClientCredentialsTokenRequest<'_, TE, TR>
pub fn exchange_client_credentials( &self, ) -> ClientCredentialsTokenRequest<'_, TE, TR>
Request an access token using the Client Credentials Flow.
Requires set_token_uri() to have been previously
called to set the token endpoint.
Sourcepub fn exchange_code(
&self,
code: AuthorizationCode,
) -> CodeTokenRequest<'_, TE, TR>
pub fn exchange_code( &self, code: AuthorizationCode, ) -> CodeTokenRequest<'_, TE, TR>
Exchange a code returned during the Authorization Code Flow for an access token.
Acquires ownership of the code because authorization codes may only be used once to
retrieve an access token from the authorization server.
Requires set_token_uri() to have been previously
called to set the token endpoint.
Sourcepub fn exchange_device_access_token<'a, EF>(
&'a self,
auth_response: &'a DeviceAuthorizationResponse<EF>,
) -> DeviceAccessTokenRequest<'a, 'static, TR, EF>where
EF: ExtraDeviceAuthorizationFields,
pub fn exchange_device_access_token<'a, EF>(
&'a self,
auth_response: &'a DeviceAuthorizationResponse<EF>,
) -> DeviceAccessTokenRequest<'a, 'static, TR, EF>where
EF: ExtraDeviceAuthorizationFields,
Exchange an RFC 8628 Device Authorization
Response returned by exchange_device_code() for an access
token.
Requires set_token_uri() to have been previously
called to set the token endpoint.
Sourcepub fn exchange_password<'a>(
&'a self,
username: &'a ResourceOwnerUsername,
password: &'a ResourceOwnerPassword,
) -> PasswordTokenRequest<'a, TE, TR>
pub fn exchange_password<'a>( &'a self, username: &'a ResourceOwnerUsername, password: &'a ResourceOwnerPassword, ) -> PasswordTokenRequest<'a, TE, TR>
Request an access token using the Resource Owner Password Credentials Flow.
Requires
set_token_uri() to have
been previously called to set the token endpoint.
Sourcepub fn exchange_refresh_token<'a>(
&'a self,
refresh_token: &'a RefreshToken,
) -> RefreshTokenRequest<'a, TE, TR>
pub fn exchange_refresh_token<'a>( &'a self, refresh_token: &'a RefreshToken, ) -> RefreshTokenRequest<'a, TE, TR>
Exchange a refresh token for an access token.
See https://tools.ietf.org/html/rfc6749#section-6.
Requires
set_token_uri() to have
been previously called to set the token endpoint.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, EndpointMaybeSet, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods with a possibly-set token endpoint after calling
from_provider_metadata().
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, EndpointMaybeSet, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods with a possibly-set token endpoint after calling
from_provider_metadata().
Sourcepub fn exchange_client_credentials(
&self,
) -> Result<ClientCredentialsTokenRequest<'_, TE, TR>, ConfigurationError>
pub fn exchange_client_credentials( &self, ) -> Result<ClientCredentialsTokenRequest<'_, TE, TR>, ConfigurationError>
Request an access token using the Client Credentials Flow.
Requires from_provider_metadata() to have been previously
called to construct the client.
Sourcepub fn exchange_code(
&self,
code: AuthorizationCode,
) -> Result<CodeTokenRequest<'_, TE, TR>, ConfigurationError>
pub fn exchange_code( &self, code: AuthorizationCode, ) -> Result<CodeTokenRequest<'_, TE, TR>, ConfigurationError>
Exchange a code returned during the Authorization Code Flow for an access token.
Acquires ownership of the code because authorization codes may only be used once to
retrieve an access token from the authorization server.
Requires from_provider_metadata() to have been previously
called to construct the client.
Sourcepub fn exchange_device_access_token<'a, EF>(
&'a self,
auth_response: &'a DeviceAuthorizationResponse<EF>,
) -> Result<DeviceAccessTokenRequest<'a, 'static, TR, EF>, ConfigurationError>where
EF: ExtraDeviceAuthorizationFields,
pub fn exchange_device_access_token<'a, EF>(
&'a self,
auth_response: &'a DeviceAuthorizationResponse<EF>,
) -> Result<DeviceAccessTokenRequest<'a, 'static, TR, EF>, ConfigurationError>where
EF: ExtraDeviceAuthorizationFields,
Exchange an RFC 8628 Device Authorization
Response returned by exchange_device_code() for an access
token.
Requires from_provider_metadata() to have been previously
called to construct the client.
Sourcepub fn exchange_password<'a>(
&'a self,
username: &'a ResourceOwnerUsername,
password: &'a ResourceOwnerPassword,
) -> Result<PasswordTokenRequest<'a, TE, TR>, ConfigurationError>
pub fn exchange_password<'a>( &'a self, username: &'a ResourceOwnerUsername, password: &'a ResourceOwnerPassword, ) -> Result<PasswordTokenRequest<'a, TE, TR>, ConfigurationError>
Request an access token using the Resource Owner Password Credentials Flow.
Requires from_provider_metadata() to have been previously
called to construct the client.
Sourcepub fn exchange_refresh_token<'a>(
&'a self,
refresh_token: &'a RefreshToken,
) -> Result<RefreshTokenRequest<'a, TE, TR>, ConfigurationError>
pub fn exchange_refresh_token<'a>( &'a self, refresh_token: &'a RefreshToken, ) -> Result<RefreshTokenRequest<'a, TE, TR>, ConfigurationError>
Exchange a refresh token for an access token.
See https://tools.ietf.org/html/rfc6749#section-6.
Requires from_provider_metadata() to have been previously
called to construct the client.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, EndpointSet, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring a device authorization endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, EndpointSet, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring a device authorization endpoint.
Sourcepub fn exchange_device_code(&self) -> DeviceAuthorizationRequest<'_, TE>
pub fn exchange_device_code(&self) -> DeviceAuthorizationRequest<'_, TE>
Begin the RFC 8628 Device Authorization Flow and retrieve a Device Authorization Response.
Requires
set_device_authorization_url() to have
been previously called to set the device authorization endpoint.
Return the RFC 8628 device authorization endpoint used for the Device Authorization Flow.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, EndpointSet, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring an introspection endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, EndpointSet, HasRevocationUrl, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring an introspection endpoint.
Sourcepub fn introspect<'a>(
&'a self,
token: &'a AccessToken,
) -> IntrospectionRequest<'a, TE, TIR>
pub fn introspect<'a>( &'a self, token: &'a AccessToken, ) -> IntrospectionRequest<'a, TE, TIR>
Retrieve metadata for an access token using the
RFC 7662 introspection endpoint.
Requires set_introspection_url() to have been previously
called to set the introspection endpoint.
Sourcepub fn introspection_url(&self) -> &IntrospectionUrl
pub fn introspection_url(&self) -> &IntrospectionUrl
Return the RFC 7662 introspection endpoint.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, EndpointSet, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring a revocation endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasTokenUrl, HasUserInfoUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, EndpointSet, HasTokenUrl, HasUserInfoUrl>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasTokenUrl: EndpointState,
HasUserInfoUrl: EndpointState,
Methods requiring a revocation endpoint.
Sourcepub fn revoke_token(
&self,
token: RT,
) -> Result<RevocationRequest<'_, RT, TRE>, ConfigurationError>
pub fn revoke_token( &self, token: RT, ) -> Result<RevocationRequest<'_, RT, TRE>, ConfigurationError>
Revoke an access or refresh token using the RFC 7009 revocation endpoint.
Requires set_revocation_url() to have been previously
called to set the revocation endpoint.
Sourcepub fn revocation_url(&self) -> &RevocationUrl
pub fn revocation_url(&self) -> &RevocationUrl
Return the RFC 7009 revocation endpoint.
See revoke_token().
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, EndpointSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
Methods requiring a user info endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, EndpointSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
Methods requiring a user info endpoint.
Sourcepub fn user_info(
&self,
access_token: AccessToken,
expected_subject: Option<SubjectIdentifier>,
) -> UserInfoRequest<'_, JE, K>
pub fn user_info( &self, access_token: AccessToken, expected_subject: Option<SubjectIdentifier>, ) -> UserInfoRequest<'_, JE, K>
Request info about the user associated with the given access token.
Requires set_user_info_url() to have been previously
called to set the user info endpoint.
To help protect against token substitution attacks, this function optionally allows clients
to provide the subject identifier whose user info they expect to receive. If provided and
the subject returned by the OpenID Connect Provider does not match, the
UserInfoRequest::request or UserInfoRequest::request_async functions will return
UserInfoError::ClaimsVerification. If set to
None, any subject is accepted.
Sourcepub fn user_info_url(&self) -> &UserInfoUrl
pub fn user_info_url(&self) -> &UserInfoUrl
Return the user info endpoint.
See ‘user_info()’.
Sourceimpl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, EndpointMaybeSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
Methods with a possibly-set user info endpoint.
impl<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl> Client<AC, AD, GC, JE, K, P, TE, TR, TIR, RT, TRE, HasAuthUrl, HasDeviceAuthUrl, HasIntrospectionUrl, HasRevocationUrl, HasTokenUrl, EndpointMaybeSet>where
AC: AdditionalClaims,
AD: AuthDisplay,
GC: GenderClaim,
JE: JweContentEncryptionAlgorithm<KeyType = <K::SigningAlgorithm as JwsSigningAlgorithm>::KeyType>,
K: JsonWebKey,
P: AuthPrompt,
TE: ErrorResponse + 'static,
TR: TokenResponse<AC, GC, JE, K::SigningAlgorithm>,
TIR: TokenIntrospectionResponse,
RT: RevocableToken,
TRE: ErrorResponse + 'static,
HasAuthUrl: EndpointState,
HasDeviceAuthUrl: EndpointState,
HasIntrospectionUrl: EndpointState,
HasRevocationUrl: EndpointState,
HasTokenUrl: EndpointState,
Methods with a possibly-set user info endpoint.
Sourcepub fn user_info(
&self,
access_token: AccessToken,
expected_subject: Option<SubjectIdentifier>,
) -> Result<UserInfoRequest<'_, JE, K>, ConfigurationError>
pub fn user_info( &self, access_token: AccessToken, expected_subject: Option<SubjectIdentifier>, ) -> Result<UserInfoRequest<'_, JE, K>, ConfigurationError>
Request info about the user associated with the given access token.
Requires from_provider_metadata() to have been previously
called to construct the client.
To help protect against token substitution attacks, this function optionally allows clients
to provide the subject identifier whose user info they expect to receive. If provided and
the subject returned by the OpenID Connect Provider does not match, the
UserInfoRequest::request or UserInfoRequest::request_async functions will return
UserInfoError::ClaimsVerification. If set to
None, any subject is accepted.
Sourcepub fn user_info_url(&self) -> Option<&UserInfoUrl>
pub fn user_info_url(&self) -> Option<&UserInfoUrl>
Return the user info endpoint.
See ‘user_info()’.