pub trait ResponseType:
AsRef<str>
+ Debug
+ DeserializeOwned
+ Serialize
+ 'static {
// Required method
fn to_oauth2(&self) -> ResponseType;
}Expand description
Response type indicating the desired authorization processing flow, including what parameters are returned from the endpoints used.
Required Methods
Sourcefn to_oauth2(&self) -> ResponseType
fn to_oauth2(&self) -> ResponseType
Converts this OpenID Connect response type to an oauth2::ResponseType used by the
underlying oauth2 crate.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".